.. KM3Flux documentation master file

KM3Flux
=======

.. image:: https://readthedocs.org/projects/km3flux/badge/?version=latest

KM3Flux is a collection of neutrino flux models + assorted utilities for
computing event weights.

Install
-------

This is developed on python 3.6. Lower versions (especially py2)
might or might not work.

Install the dependencies

* numpy 
* pandas
* h5py
* pytables 

In your python env, do

  pip install km3flux

Contents
--------

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2
    
    examples
    api

* :ref:`genindex`
